@@ -17,7 +17,9 @@ class AppService(app_external_pb2_grpc.ExternalAppServicer):
             [
                 app_external_pb2.ProcessorExternalInfo(
                     name=processor["name"],
-                    attributeSchema=json.dumps(processor["attributes_schema"]),
+                    attributeSchema=json.dumps(processor["attributes_schema"])
+                    if processor.get("attributes_schema")
+                    else "",
                 )
                 for processor in info["processors"]
             ]
